<?php

namespace App\Entity;

use App\Repository\InputRecipeMaterialRepository;
use Doctrine\ORM\Mapping as ORM;
use Stringable;
use Symfony\Bridge\Doctrine\Validator\Constraints\UniqueEntity;
use Symfony\Component\Validator\Constraints as Assert;

/**
 * A material consumed by a recipe
 */
#[ORM\Entity(repositoryClass: InputRecipeMaterialRepository::class)]
#[ORM\UniqueConstraint(fields: ['recipe', 'material'])]
#[UniqueEntity(fields: ['recipe', 'material'], message: 'Ce matériau est déjà consommé par cette recette')]
class InputRecipeMaterial implements Stringable {
    use TBaseEntity;

    /**
     * @var Recipe|null The recipe
     */
    #[ORM\ManyToOne(inversedBy: 'consumedMaterials')]
    #[ORM\JoinColumn(nullable: false, onDelete: 'CASCADE')]
    #[Assert\NotNull(message: 'Veuillez sélectionner une recette')]
    #[Assert\Valid]
    private ?Recipe $recipe = null;
    /**
     * @var Material|null The material
     */
    #[ORM\ManyToOne]
    #[ORM\JoinColumn(nullable: false)]
    #[Assert\NotNull(message: 'Veuillez sélectionner un matériau')]
    #[Assert\Valid]
    private ?Material $material = null;

    /**
     * @var int|null The consumed quantity
     */
    #[ORM\Column]
    #[Assert\Type(type: 'integer', message: 'La quantité consommée doit être un nombre entier')]
    #[Assert\NotNull(message: 'Veuillez saisir une quantité consommée')]
    #[Assert\Positive(message: 'La quantité consommée doit être strictement positive')]
    private ?int $consumedQuantity = null;

    /**
     * @inheritDoc
     */
    public function __toString (): string {
        return $this->getMaterial()->getName() . ' x' . $this->getConsumedQuantity();
    }

    /**
     * The recipe
     *
     * @return Recipe|null The recipe
     */
    public function getRecipe (): ?Recipe {
        return $this->recipe;
    }
    /**
     * Set the recipe
     *
     * @param Recipe|null $recipe The recipe
     *
     * @return $this
     */
    public function setRecipe (?Recipe $recipe): static {
        $this->recipe = $recipe;

        return $this;
    }

    /**
     * The material
     *
     * @return Material|null The material
     */
    public function getMaterial (): ?Material {
        return $this->material;
    }
    /**
     * Set the material
     *
     * @param Material|null $material The material
     *
     * @return $this
     */
    public function setMaterial (?Material $material): static {
        $this->material = $material;

        return $this;
    }

    /**
     * The consumed quantity
     *
     * @return int|null The consumed quantity
     */
    public function getConsumedQuantity (): ?int {
        return $this->consumedQuantity;
    }
    /**
     * Set the consumed quantity
     *
     * @param int $consumedQuantity The consumed quantity
     *
     * @return $this
     */
    public function setConsumedQuantity (int $consumedQuantity): static {
        $this->consumedQuantity = $consumedQuantity;

        return $this;
    }
}
