<?php

namespace App\Form\Config;

use App\Entity\Machine;
use App\Entity\Recipe;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

/**
 * The form for editing a recipe
 */
class RecipeEditForm extends AbstractType {
    /**
     * @inheritDoc
     */
    public function configureOptions (OptionsResolver $resolver): void {
        $resolver->setDefaults(
            [
                'data_class' => Recipe::class,
            ]
        );
    }

    /**
     * @inheritDoc
     */
    public function buildForm (FormBuilderInterface $builder, array $options): void {
        $builder
            ->add('machine', null, [
                'label'       => 'Machine',
                'choice_attr' => function (Machine $machine, string $index, string $machineId): array {
                    return [
                        'data-machine' => json_encode([
                            'labelExtraInfo1' => $machine->getLabelExtraInfo1(),
                            'labelExtraInfo2' => $machine->getLabelExtraInfo2(),
                        ]),
                    ];
                },
            ])
            ->add('machineExtraInfo1', TextType::class, [
                'label'    => 'Information complémentaire n° 1',
                'required' => false,
                'row_attr' => [
                    'class' => 'd-none mb-3',
                ],
            ])
            ->add('machineExtraInfo2', null, [
                'label'    => 'Information complémentaire n° 2',
                'required' => false,
                'row_attr' => [
                    'class' => 'd-none mb-3',
                ],
            ])
            ->add('craftingTime', null, [
                'label' => 'Temps de production',
            ])
            ->add('consumedMaterials', CollectionType::class, [
                'label'         => 'Matériaux consommés',
                'entry_type'    => InputRecipeMaterialForm::class,
                'entry_options' => [
                    'label' => false,
                ],
                'allow_add'     => true,
                'allow_delete'  => true,
                'by_reference'  => false,
            ])
            ->add('producedMaterials', CollectionType::class, [
                'label'         => 'Matériaux produits',
                'entry_type'    => OutputRecipeMaterialForm::class,
                'entry_options' => [
                    'label' => false,
                ],
                'allow_add'     => true,
                'allow_delete'  => true,
                'by_reference'  => false,
            ])
            ->add('submit', SubmitType::class, [
                'label' => 'Enregistrer',
            ]);
    }
}